@@ -1,8 +1,6 @@
 package addon_test
 
 import (
-	"time"
-
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
@@ -14,7 +12,7 @@ import (
 var _ = Describe("Addon", func() {
 	When("the version is supported", func() {
 		It("does not error", func() {
-			_, err := addon.New(&api.ClusterConfig{Metadata: &api.ClusterMeta{Version: "1.18"}}, &mocksv2.EKS{}, nil, false, nil, nil, 5*time.Minute)
+			_, err := addon.New(&api.ClusterConfig{Metadata: &api.ClusterMeta{Version: "1.18"}}, &mocksv2.EKS{}, nil, false, nil, nil)
 			Expect(err).NotTo(HaveOccurred())
 		})
 	})
