@@ -106,6 +106,15 @@ func newFakeClusterWithEndpoints(private, public bool, name string) *ekstypes.Cl
 	return cluster
 }
 
+func clusterConfigWithSubnets(publicSubnets, privateSubnets api.AZSubnetMapping) *api.ClusterConfig {
+	cfg := api.NewClusterConfig()
+	cfg.VPC.Subnets = &api.ClusterSubnets{
+		Private: privateSubnets,
+		Public:  publicSubnets,
+	}
+	return cfg
+}
+
 var _ = Describe("VPC", func() {
 	Describe("SplitInto16", func() {
 		It("splits the block into 16", func() {
@@ -597,6 +606,113 @@ var _ = Describe("VPC", func() {
 				}, nil)
 			},
 		}),
+
+		Entry("cluster spec provided - subnets with invalid AZs", useFromClusterCase{
+			cfg: clusterConfigWithSubnets(
+				api.AZSubnetMapping{
+					"public-1": {
+						ID: "subnet-public-1",
+					},
+					// public-2 will not be on the stack,
+					// hence fetching config from stack
+					// won't resolve the AZ for this subnet
+					"public-2": {
+						ID: "subnet-public-2",
+					},
+				},
+				api.AZSubnetMapping{
+					"private-1": {
+						ID: "subnet-private-1",
+					},
+					// private-2 will not be on the stack,
+					// hence fetching config from stack
+					// won't resolve the AZ for this subnet
+					"private-2": {
+						ID: "subnet-private-2",
+					},
+				}),
+			stack: &cfntypes.Stack{
+				Outputs: []cfntypes.Output{
+					{
+						OutputKey:   aws.String("VPC"),
+						OutputValue: aws.String("vpc-123"),
+					},
+					{
+						OutputKey:   aws.String("SecurityGroup"),
+						OutputValue: aws.String("sg-123"),
+					},
+					{
+						OutputKey:   aws.String("SubnetsPublic"),
+						OutputValue: aws.String("subnet-public-1"),
+					},
+					{
+						OutputKey:   aws.String("SubnetsPrivate"),
+						OutputValue: aws.String("subnet-private-1"),
+					},
+				},
+			},
+			mockEC2: func(ec2Mock *mocksv2.EC2) {
+				ec2Mock.On("DescribeSubnets", Anything, Anything).Return(func(_ context.Context, input *ec2.DescribeSubnetsInput, _ ...func(options *ec2.Options)) *ec2.DescribeSubnetsOutput {
+					subnet := ec2types.Subnet{
+						SubnetId: aws.String(input.SubnetIds[0]),
+						VpcId:    aws.String("vpc-123"),
+					}
+					if input.SubnetIds[0] == "subnet-public-1" {
+						subnet.AvailabilityZone = aws.String("us-west-2a")
+						subnet.CidrBlock = aws.String("192.168.0.0/20")
+					} else {
+						subnet.AvailabilityZone = aws.String("us-west-2a")
+						subnet.CidrBlock = aws.String("192.168.0.16/20")
+					}
+					return &ec2.DescribeSubnetsOutput{
+						Subnets: []ec2types.Subnet{subnet},
+					}
+				}, nil).On("DescribeVpcs", Anything, Anything).Return(&ec2.DescribeVpcsOutput{
+					Vpcs: []ec2types.Vpc{
+						{
+							VpcId:     aws.String("vpc-123"),
+							CidrBlock: aws.String("192.168.0.0/20"),
+						},
+					},
+				}, nil)
+			},
+			expectedVPC: &api.ClusterVPC{
+				Network: api.Network{
+					ID:   "vpc-123",
+					CIDR: ipnet.MustParseCIDR("192.168.0.0/20"),
+				},
+				SecurityGroup: "sg-123",
+				Subnets: &api.ClusterSubnets{
+					Public: api.AZSubnetMapping{
+						"public-1": api.AZSubnetSpec{
+							ID:   "subnet-public-1",
+							AZ:   "us-west-2a",
+							CIDR: ipnet.MustParseCIDR("192.168.0.0/20"),
+						},
+					},
+					Private: api.AZSubnetMapping{
+						"private-1": api.AZSubnetSpec{
+							ID:   "subnet-private-1",
+							AZ:   "us-west-2a",
+							CIDR: ipnet.MustParseCIDR("192.168.0.16/20"),
+						},
+					},
+				},
+				LocalZoneSubnets: &api.ClusterSubnets{
+					Private: api.NewAZSubnetMapping(),
+					Public:  api.NewAZSubnetMapping(),
+				},
+				ManageSharedNodeSecurityGroupRules: aws.Bool(true),
+				AutoAllocateIPv6:                   aws.Bool(false),
+				NAT: &api.ClusterNAT{
+					Gateway: aws.String("Single"),
+				},
+				ClusterEndpoints: &api.ClusterEndpoints{
+					PublicAccess:  aws.Bool(true),
+					PrivateAccess: aws.Bool(true),
+				},
+			},
+		}),
 	)
 
 	DescribeTable("importVPC",
@@ -875,10 +991,54 @@ var _ = Describe("VPC", func() {
 		AvailabilityZones: []string{"az1", "az2", "az3"},
 	}
 
+	cfgWithAllAZAndNGs := &api.ClusterConfig{
+		NodeGroups: []*api.NodeGroup{
+			{
+				NodeGroupBase: &api.NodeGroupBase{
+					Subnets: []string{"invalid id"},
+				},
+			},
+		},
+		ManagedNodeGroups: []*api.ManagedNodeGroup{
+			{
+				NodeGroupBase: &api.NodeGroupBase{
+					Subnets: []string{"invalid id"},
+				},
+			},
+		},
+		VPC: &api.ClusterVPC{
+			Subnets: &api.ClusterSubnets{
+				Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
+					"az1": {
+						ID: "private1",
+					},
+					"az2": {
+						ID: "private2",
+					},
+					"az3": {
+						ID: "private3",
+					},
+				}),
+				Public: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
+					"az1": {
+						ID: "public1",
+					},
+					"az2": {
+						ID: "public2",
+					},
+					"az3": {
+						ID: "public3",
+					},
+				}),
+			},
+		},
+		AvailabilityZones: []string{"az1", "az2", "az3"},
+	}
+
 	DescribeTable("clean up the subnets details in spec if given AZ is invalid",
 		func(e cleanupSubnetsCase) {
 			cleanupSubnets(e.cfg)
-			Expect(e.cfg).To(Equal(cfgWithAllAZ))
+			Expect(e.cfg).To(Equal(e.want))
 		},
 
 		Entry("All AZs are valid", cleanupSubnetsCase{
@@ -911,10 +1071,25 @@ var _ = Describe("VPC", func() {
 				},
 				AvailabilityZones: []string{"az1", "az2", "az3"},
 			},
+			want: cfgWithAllAZ,
 		}),
 
 		Entry("Private subnet with invalid AZ", cleanupSubnetsCase{
 			cfg: &api.ClusterConfig{
+				NodeGroups: []*api.NodeGroup{
+					{
+						NodeGroupBase: &api.NodeGroupBase{
+							Subnets: []string{"invalid AZ"},
+						},
+					},
+				},
+				ManagedNodeGroups: []*api.ManagedNodeGroup{
+					{
+						NodeGroupBase: &api.NodeGroupBase{
+							Subnets: []string{"invalid AZ"},
+						},
+					},
+				},
 				VPC: &api.ClusterVPC{
 					Subnets: &api.ClusterSubnets{
 						Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
@@ -928,7 +1103,7 @@ var _ = Describe("VPC", func() {
 								ID: "private3",
 							},
 							"invalid AZ": {
-								ID: "invalid private id",
+								ID: "invalid id",
 							},
 						}),
 						Public: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
@@ -946,10 +1121,24 @@ var _ = Describe("VPC", func() {
 				},
 				AvailabilityZones: []string{"az1", "az2", "az3"},
 			},
-			want: cfgWithAllAZ,
+			want: cfgWithAllAZAndNGs,
 		}),
 		Entry("Public subnet with invalid AZ", cleanupSubnetsCase{
 			cfg: &api.ClusterConfig{
+				NodeGroups: []*api.NodeGroup{
+					{
+						NodeGroupBase: &api.NodeGroupBase{
+							Subnets: []string{"invalid AZ"},
+						},
+					},
+				},
+				ManagedNodeGroups: []*api.ManagedNodeGroup{
+					{
+						NodeGroupBase: &api.NodeGroupBase{
+							Subnets: []string{"invalid AZ"},
+						},
+					},
+				},
 				VPC: &api.ClusterVPC{
 					Subnets: &api.ClusterSubnets{
 						Private: api.AZSubnetMappingFromMap(map[string]api.AZSubnetSpec{
@@ -974,14 +1163,14 @@ var _ = Describe("VPC", func() {
 								ID: "public3",
 							},
 							"invalid AZ": {
-								ID: "invalid public id",
+								ID: "invalid id",
 							},
 						}),
 					},
 				},
 				AvailabilityZones: []string{"az1", "az2", "az3"},
 			},
-			want: cfgWithAllAZ,
+			want: cfgWithAllAZAndNGs,
 		}),
 	)
 
